@@ -14,7 +14,7 @@ VERSION = "1.6.8"
 MAX_RETRIES = 5
 PUBLIC_AUTH_SERVER = "https://auth.lightwaverf.com/token"
 PUBLIC_API = "https://publicapi.lightwaverf.com/v1/"
-RGB_FLOOR = int("0x1B", 16) #Lightwave app seems to floor RGB values here, let's do the same
+RGB_FLOOR = int("0x0", 16) #Previously the Lightwave app floored RGB values, but it doesn't any more
 
 #TODO adapt async_connect calls to respond to connection failure
 
@@ -152,7 +152,7 @@ class LWLink2:
     @asyncio.coroutine
     def _consumer_handler(self):
         while True:
-            _LOGGER.debug("consumer_handler: starting consumer handler")
+            _LOGGER.debug("consumer_handler: Starting consumer handler")
             try:
                 mess = yield from self._websocket.receive()
                 _LOGGER.debug("consumer_handler: Received %s", mess)
@@ -192,10 +192,11 @@ class LWLink2:
                     for key, flag in self._transactions.items():
                         flag.set()
                     self._transactions = {}
+                    self._authtoken = None
                     asyncio.ensure_future(self.async_connect())
-                    _LOGGER.info("consumer_handler: Websocket reopened in message handler")
+                    _LOGGER.info("consumer_handler: Websocket reconnect requested by message handler")
             except AttributeError:  # websocket is None if not set up, just wait for a while
-                _LOGGER.debug("consumer_handler: attribute error, sleeping for 1 sec")
+                _LOGGER.debug("consumer_handler: websocket not ready, sleeping for 1 sec")
                 yield from asyncio.sleep(1)
             except Exception as exp:
                 _LOGGER.warning("consumer_handler: unhandled exception ('{}')".format(exp))
@@ -381,7 +382,7 @@ class LWLink2:
     async def _connect_to_server(self):
         if (not self._websocket) or self._websocket.closed:
             _LOGGER.debug("connect_to_server: Connecting to websocket")
-            self._websocket = await self._session.ws_connect(TRANS_SERVER)
+            self._websocket = await self._session.ws_connect(TRANS_SERVER, heartbeat=10)
         return await self._authenticate_websocket()
 
     async def _authenticate_websocket(self):
